@@ -30,12 +30,23 @@ int fferror_print(char *sourcecode_filename, int line, const char *function_name
 /* remove \n, assumes UNIX line endings! */
 char* ffnchomp(char *s, size_t len)
 {
-  len -= 1;
-  if(len >= 0 && s[len] == '\n')
+  if(len >= 1 && s[--len] == '\n')
     s[len] = '\0';
 
   return s;
 }
 
+/* replacement for strtol streamlined for speed */
+unsigned long parse_ulong(const char *s, const char** end)
+{
+  const unsigned int base = 10;
+  unsigned long l = 0UL;
+  unsigned char *c = (unsigned char*)s;
+  for(unsigned int digit = *c-'0'; *c && digit < base; digit = *++c-'0')
+    l = (l * base) + digit;
+  *end = (char *)c;
+  return l;
+}
+
 /* vim: ts=2 sw=2 et
 */
